@@ -1,8 +1,6 @@
 import json
 from pathlib import Path
 
-# so far the config object only stores the path
-# in which to look for cards
 class Config(dict):
 	path = Path(__file__).parent / 'config.json'
 	
@@ -18,7 +16,17 @@ class Config(dict):
 			json.dump(self, f)
 
 	def set_cards_path(self, path):
-		self['cards_path'] = path
+		''' vinca will look for cards in the chosen directory '''
+		self['cards_path'] = str(path)
+		self.save()
+
+	@property
+	def last_card_path(self):
+		return Path(self['last_card_path'])
+
+	@last_card_path.setter
+	def last_card_path(self, card_path):
+		self['last_card_path'] = str(card_path)
 		self.save()
 
 	@property
