@@ -11,6 +11,6 @@ def edit(card):
 	stop = datetime.datetime.now()
 	elapsed_time = min(240, (stop - start).seconds)
 
-	card.add_history(TODAY, elapsed_time, 'edit')
+	card.history.append_entry(TODAY, elapsed_time, 'edit')
 	
 	card.make_string()
