@@ -1,7 +1,5 @@
 from vinca.card import Card
-from vinca.generators.decorator import generator
 
-@generator
 def two_lines():
 	''' make a simple question and answer card '''
 	new_card = Card(create=True)
@@ -9,4 +7,4 @@ def two_lines():
 	(new_card.path / 'front').touch()
 	(new_card.path / 'back').touch()
 	new_card.edit()
-	return [new_card]
+	return new_card
