@@ -6,7 +6,7 @@ import functools
 esc = '\033['
 codes = {'reset': esc+'0m',
         'bold': esc+'1m', 'b': esc+'1m',
-        'bold_off': esc+'22m', 'b': esc+'1m',
+        'bold_off': esc+'22m',
         'light': esc+'2m', 'dim': esc+'2m',
         'italic': esc+'3m', 'it': esc+'3m',
         'underlined': esc+'4m', 'u': esc+'4m',
@@ -42,6 +42,16 @@ for key in codes:
 	globals()[key] = functools.partial(_do, cmd=key)
 
 def strip_ansi(text):
+	'''
+	>>> strip_ansi('the quick fox')
+	'the quick fox'
+	>>> strip_ansi('\033[1mBOLD')
+	'BOLD'
+	>>> strip_ansi('\033[?25l hidden cursor \033[?25h')
+	' hidden cursor '
+	>>> strip_ansi('down\033E line')
+	'down line'
+	'''
 	ansi_escape = re.compile(r'''
 	    \x1B  # ESC
 	    (?:   # 7-bit C1 Fe (except CSI)
@@ -53,5 +63,9 @@ def strip_ansi(text):
 		[@-~]   # Final byte
 	    )
 	''', re.VERBOSE)
-	result = ansi_escape.sub('', sometext)
+	result = ansi_escape.sub('', text)
 	return result
+
+if __name__=='__main__':
+	import doctest
+	doctest.testmod()
