@@ -20,7 +20,7 @@ def to_path(arg):
 		return arg
 	p = Path(arg)
 	if not p.exists():
-		raise FileNotFoundError
+		raise FileNotFoundError(p)
 	return p
 
 def to_date(arg):
