@@ -18,13 +18,18 @@ def raw_terminal():
 	old_settings = termios.tcgetattr(fd) # save state of terminal
 
 	try:
+		# the tty has two modes:
+		# 'cooked' waits for the user to press enter
+		# 'raw' passes the typed characters immediately
 		tty.setraw(fd)
 		yield fd
 	finally:
+		# restore state of terminal
 		termios.tcsetattr(fd, termios.TCSADRAIN, old_settings)
-		sys.stdout.flush() # restore state of terminal
+		sys.stdout.flush() 
 
 
 def readkey():
 	with raw_terminal() as fd:
+		# a single key can be represented by up to 4 bytes
 		return os.read(fd, 4).decode()
