@@ -6,7 +6,7 @@ TODAY = datetime.date.today()
 	
 GRADE_DICT = {'x': 'delete', 'd': 'delete',
 	      'q': 'exit', '\x1b': 'exit',
-	      'p': 'preview',
+	      'p': 'preview', '0': 'preview',
 	      '1': 'again',
 	      '2': 'hard',
 	      '3': 'good', ' ': 'good', '\r': 'good', '\n': 'good',
@@ -26,7 +26,7 @@ def review(card):
 
 	grade = GRADE_DICT[key] if key in GRADE_DICT else 'exit'
 
-	card.add_history(TODAY, elapsed, grade)
+	card.history.append_entry(TODAY, elapsed, grade)
 
 def make_string(card):
 	m = importlib.import_module('.'+card.reviewer, package = 'vinca.reviewers')
