@@ -8,10 +8,9 @@ def review(card):
 		lines = (card.path / 'lines').read_text().splitlines()
 		print(lines.pop(0))  # print the first line
 		for line in lines:
-			readkey() # press any key to continue
-			# TODO abort
-			print(line)
-		print('\n(end)')
+			char = readkey() # press any key to continue
+			if char in ['x','a','q']: # immediate exit actions to abort the review
+				return char
 
 		# grade the card
 		char = readkey()
