@@ -7,11 +7,13 @@ tags_path = vinca_path / 'tags'
 
 class TagsCache(list):
 	def __init__(self):
-		self[:] = tags_path.read_text().splitlines()
+		tags = tags_path.read_text().splitlines()
+		super().__init__(tags)
 
 	def update(self):
 		'rebuild the tags list'
-		all_cards = [vinca.card.Card(int(id.name)) for id in config.cards_path.iterdir()] 
+		# TODO a collector module
+		all_cards = [vinca.card.Card(p.name) for p in config.cards_path.iterdir()] 
 		self[:] = [tag for card in all_cards for tag in card.tags]
 		self.save()
 
